@@ -455,6 +455,10 @@ def load(**kwargs):
         elif daconfig['checkin interval'] > 0 and daconfig['checkin interval'] < 1000:
             config_error("checkin interval must be at least 1000, if not 0.")
             del daconfig['checkin interval']
+    if daconfig.get('checkin interval', 5) == 0:
+        daconfig['enable monitor'] = False
+    else:
+        daconfig['enable monitor'] = True
     if daconfig.get('default icons', None) == 'font awesome':
         daconfig['use font awesome'] = True
     if 'websockets port' in daconfig and daconfig['websockets port']:
@@ -499,6 +503,8 @@ def load(**kwargs):
         daconfig['root'] = '/'
     if 'web server' not in daconfig or not daconfig['web server']:
         daconfig['web server'] = 'nginx'
+    if 'table css class' not in daconfig or not isinstance(daconfig['table css class'], str):
+        daconfig['table css class'] = 'table table-striped'
     if env_true_false('ENVIRONMENT_TAKES_PRECEDENCE'):
         messages = list()
         for env_var, key in (('DBPREFIX', 'prefix'), ('DBNAME', 'name'), ('DBUSER', 'user'), ('DBPASSWORD', 'password'), ('DBHOST', 'host'), ('DBPORT', 'port'), ('DBTABLEPREFIX', 'table prefix'), ('DBBACKUP', 'backup')):
